# -*- coding: utf-8 -*-
#
# Copyright (C) 2015-2019 Bitergia
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
# Authors:
#   Alvaro del Castillo San Felix <acs@bitergia.com>
#

from .elastic import ElasticOcean
from ..elastic_mapping import Mapping as BaseMapping
from ..elastic_items import ElasticItems
from ..enriched.utils import anonymize_url


class Mapping(BaseMapping):

    @staticmethod
    def get_elastic_mappings(es_major):
        """Get Elasticsearch mapping.

        Non dynamic discovery of type for:
            * data.extensions

        :param es_major: major version of Elasticsearch, as string
        :returns:        dictionary with a key, 'items', with the mapping
        """

        mapping = '''
         {
            "dynamic":true,
                "properties": {
                    "data": {
                        "properties": {
                            "extensions": {
                                "dynamic":false,
                                "properties": {}
                            },
                            "ancestors": {
                                "properties": {
                                    "extensions": {
                                        "dynamic":false,
                                        "properties": {}
                                    }
                                }
                            },
                            "body": {
                                "dynamic":false,
                                "properties": {}
                            }
                        }
                    }
                }
        }
        '''

        return {"items": mapping}


class ConfluenceOcean(ElasticOcean):
    """Confluence Ocean feeder"""

    mapping = Mapping

    def _fix_item(self, item):
        item['origin'] = anonymize_url(item['origin'])
        item['tag'] = anonymize_url(item['tag'])
        item['data']['content_url'] = anonymize_url(item['data']['content_url'])

    @classmethod
    def get_perceval_params_from_url(cls, url):
        url, spaces = ElasticItems.extract_repo_tags(url, "spaces")
        params = [url]
        if spaces:
            params += ["--spaces"] + spaces
        return params
